diff --git a/3d-viewer/3d_rendering/3d_render_raytracing/create_scene.cpp b/3d-viewer/3d_rendering/3d_render_raytracing/create_scene.cpp
index 97d6972111..f04b958080 100644
--- a/3d-viewer/3d_rendering/3d_render_raytracing/create_scene.cpp
+++ b/3d-viewer/3d_rendering/3d_render_raytracing/create_scene.cpp
@@ -471,7 +471,7 @@ void RENDER_3D_RAYTRACE::Reload( REPORTER* aStatusReporter, REPORTER* aWarningRe
             for( int iOutlinePolyIdx = 0; iOutlinePolyIdx < antiboardPoly.OutlineCount();
                  iOutlinePolyIdx++ )
             {
-                CovertPolygonToBlocks( antiboardPoly,
+                ConvertPolygonToBlocks( antiboardPoly,
                         *m_antioutlineBoard2dObjects, m_boardAdapter.BiuTo3dUnits(), -1.0f,
                         *dynamic_cast<const BOARD_ITEM*>( m_boardAdapter.GetBoard() ),
                         iOutlinePolyIdx );
@@ -483,7 +483,7 @@ void RENDER_3D_RAYTRACE::Reload( REPORTER* aStatusReporter, REPORTER* aWarningRe
 
             for( int iOutlinePolyIdx = 0; iOutlinePolyIdx < outlineCount; iOutlinePolyIdx++ )
             {
-                CovertPolygonToBlocks( boardPolyCopy, *m_outlineBoard2dObjects,
+                ConvertPolygonToBlocks( boardPolyCopy, *m_outlineBoard2dObjects,
                                        m_boardAdapter.BiuTo3dUnits(), divFactor,
                                        *dynamic_cast<const BOARD_ITEM*>( m_boardAdapter.GetBoard() ),
                                        iOutlinePolyIdx );
diff --git a/3d-viewer/3d_rendering/3d_render_raytracing/shapes2D/polygon_2d.cpp b/3d-viewer/3d_rendering/3d_render_raytracing/shapes2D/polygon_2d.cpp
index 863172ed9d..bcba4dff31 100644
--- a/3d-viewer/3d_rendering/3d_render_raytracing/shapes2D/polygon_2d.cpp
+++ b/3d-viewer/3d_rendering/3d_render_raytracing/shapes2D/polygon_2d.cpp
@@ -375,9 +375,9 @@ static void polygon_Convert( const SHAPE_LINE_CHAIN& aPath, SEGMENTS& aOutSegmen
 }
 
 
-void CovertPolygonToBlocks( const SHAPE_POLY_SET& aMainPath, CONTAINER_2D_BASE& aDstContainer,
-                            float aBiuTo3dUnitsScale, float aDivFactor,
-                            const BOARD_ITEM& aBoardItem, int aPolyIndex )
+void ConvertPolygonToBlocks( const SHAPE_POLY_SET& aMainPath, CONTAINER_2D_BASE& aDstContainer,
+                             float aBiuTo3dUnitsScale, float aDivFactor,
+                             const BOARD_ITEM& aBoardItem, int aPolyIndex )
 {
     // Get the path
     wxASSERT( aPolyIndex < aMainPath.OutlineCount() );
diff --git a/3d-viewer/3d_rendering/3d_render_raytracing/shapes2D/polygon_2d.h b/3d-viewer/3d_rendering/3d_render_raytracing/shapes2D/polygon_2d.h
index b7218fd064..544b15d287 100644
--- a/3d-viewer/3d_rendering/3d_render_raytracing/shapes2D/polygon_2d.h
+++ b/3d-viewer/3d_rendering/3d_render_raytracing/shapes2D/polygon_2d.h
@@ -148,7 +148,7 @@ public:
  * @param aDivFactor a division factor (in 3Dunits) to divide the polygon plane,
  *                   0.0f will use the internal polygon segm statistics
  */
-void CovertPolygonToBlocks( const SHAPE_POLY_SET& aMainPath, CONTAINER_2D_BASE& aDstContainer,
+void ConvertPolygonToBlocks( const SHAPE_POLY_SET& aMainPath, CONTAINER_2D_BASE& aDstContainer,
                             float aBiuTo3dUnitsScale, float aDivFactor,
                             const BOARD_ITEM& aBoardItem, int aPolyIndex );
 
diff --git a/common/gal/dpi_scaling.cpp b/common/gal/dpi_scaling.cpp
index 675dbb3647..862d8d1523 100644
--- a/common/gal/dpi_scaling.cpp
+++ b/common/gal/dpi_scaling.cpp
@@ -72,7 +72,7 @@ static OPT<double> getKiCadConfiguredScale( const COMMON_SETTINGS& aConfig )
  *
  * @return the scale factor, if set
  */
-static OPT<double> getEnviromentScale()
+static OPT<double> getEnvironmentScale()
 {
     const wxPortId port_id = wxPlatformInfo::Get().GetPortId();
     OPT<double>    scale;
@@ -109,7 +109,7 @@ double DPI_SCALING::GetScaleFactor() const
 
     if( !val )
     {
-        val = getEnviromentScale();
+        val = getEnvironmentScale();
     }
 
     if( !val && m_window )
diff --git a/common/widgets/mathplot.cpp b/common/widgets/mathplot.cpp
index dceb91e5e3..c478adf5d7 100644
--- a/common/widgets/mathplot.cpp
+++ b/common/widgets/mathplot.cpp
@@ -1548,9 +1548,9 @@ void mpScaleY::Plot( wxDC& dc, mpWindow& w )
 
         int labelW = 0;
         // Before staring cycle, calculate label height
-        int labelHeigth = 0;
+        int labelHeight = 0;
         s.Printf( fmt, n );
-        dc.GetTextExtent( s, &tx, &labelHeigth );
+        dc.GetTextExtent( s, &tx, &labelHeight );
 
         for( n = 0; n < tickCount(); n++ )
         {
diff --git a/cvpcb/tools/cvpcb_actions.cpp b/cvpcb/tools/cvpcb_actions.cpp
index b646a3ec63..67f2d95823 100644
--- a/cvpcb/tools/cvpcb_actions.cpp
+++ b/cvpcb/tools/cvpcb_actions.cpp
@@ -61,7 +61,7 @@ TOOL_ACTION CVPCB_ACTIONS::showEquFileTable( "cvpcb.Control.ShowEquFileTable",
         _( "Configure footprint association file (.equ) list.  These files are "
            "used to automatically assign footprint names from symbol values." ) );
 
-TOOL_ACTION CVPCB_ACTIONS::saveAssociations( "cvpcb.Control.SaveAssocations",
+TOOL_ACTION CVPCB_ACTIONS::saveAssociations( "cvpcb.Control.SaveAssociations",
         AS_GLOBAL,
         MD_CTRL + 'S', LEGACY_HK_NAME( "Save" ),
         _( "Save to Schematic" ),
diff --git a/eeschema/default_values.h b/eeschema/default_values.h
index fc74a1a86b..3b109f7490 100644
--- a/eeschema/default_values.h
+++ b/eeschema/default_values.h
@@ -22,8 +22,8 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  */
 
-#ifndef DEFAUT_VALUES_H
-#define DEFAUT_VALUES_H
+#ifndef DEFAULT_VALUES_H
+#define DEFAULT_VALUES_H
 
 
 #define DANGLING_SYMBOL_SIZE 12
diff --git a/gerbview/events_called_functions.cpp b/gerbview/events_called_functions.cpp
index 1cbebbd556..908efb08a1 100644
--- a/gerbview/events_called_functions.cpp
+++ b/gerbview/events_called_functions.cpp
@@ -176,7 +176,7 @@ void GERBVIEW_FRAME::ShowChangedLanguage()
     m_LayersManager->SetLayersManagerTabsText();
 
     wxAuiPaneInfo& pane_info = m_auimgr.GetPane( m_LayersManager );
-    pane_info.Caption( _( "Visibles" ) );
+    pane_info.Caption( _( "Layers Manager" ) );
     m_auimgr.Update();
 
     ReFillLayerWidget();
diff --git a/pcb_calculator/transline/coax.cpp b/pcb_calculator/transline/coax.cpp
index 8516b62e27..da084cc6dd 100644
--- a/pcb_calculator/transline/coax.cpp
+++ b/pcb_calculator/transline/coax.cpp
@@ -68,7 +68,7 @@ double COAX::alphac_coax()
 
 
 /**
- *  \f$ Z_0 = \frac{Z_{0_{\mathrm{vaccum}}}}{\sqrt{\epsilon_r}}\log_{10}\left( \frac{D_{\mathrm{out}}}{D_{\mathrm{in}}}\right) \f$
+ *  \f$ Z_0 = \frac{Z_{0_{\mathrm{vacuum}}}}{\sqrt{\epsilon_r}}\log_{10}\left( \frac{D_{\mathrm{out}}}{D_{\mathrm{in}}}\right) \f$
  *
  *  \f$ \lambda_g = \frac{c}{f \cdot \sqrt{ \epsilon_r \cdot \mu_r}} \f$
  *
@@ -92,9 +92,9 @@ void COAX::calcAnalyze()
 
 
 /**
- *  \f$ D_{\mathrm{in}} = D_{\mathrm{out}}  \cdot e^{-\frac{Z_0*\sqrt{\epsilon_r}}{2\pi \cdot  Z_{0_{\mathrm{vaccum}}}}} \f$
+ *  \f$ D_{\mathrm{in}} = D_{\mathrm{out}}  \cdot e^{-\frac{Z_0*\sqrt{\epsilon_r}}{2\pi \cdot  Z_{0_{\mathrm{vacuum}}}}} \f$
  *
- *  \f$ D_{\mathrm{out}} = D_{\mathrm{in}}  \cdot e^{ \frac{Z_0*\sqrt{\epsilon_r}}{2\pi \cdot  Z_{0_{\mathrm{vaccum}}}}} \f$
+ *  \f$ D_{\mathrm{out}} = D_{\mathrm{in}}  \cdot e^{ \frac{Z_0*\sqrt{\epsilon_r}}{2\pi \cdot  Z_{0_{\mathrm{vacuum}}}}} \f$
  *
  *  \f$ \lambda_g = \frac{c}{f \cdot \sqrt{ \epsilon_r \cdot \mu_r}} \f$
  *
diff --git a/pcb_calculator/transline/twistedpair.cpp b/pcb_calculator/transline/twistedpair.cpp
index c544baadd3..487bc1ad5c 100644
--- a/pcb_calculator/transline/twistedpair.cpp
+++ b/pcb_calculator/transline/twistedpair.cpp
@@ -52,10 +52,10 @@ TWISTEDPAIR::TWISTEDPAIR() : TRANSLINE()
  * - \f$ e_r \f$ : relative dielectric constant of the film insulation,
  * - \f$ e_{eff} \f$ : effective relative dielectric constant
  *
- * \f$ Z_0 = \frac{Z_\mathrm{VACCUM}}{\pi \cdot \sqrt{e_{eff}}}\cosh^{-1}\left(\frac{D_{out}}{D_{in}}\right) \f$
+ * \f$ Z_0 = \frac{Z_\mathrm{VACUUM}}{\pi \cdot \sqrt{e_{eff}}}\cosh^{-1}\left(\frac{D_{out}}{D_{in}}\right) \f$
  *
  * - \f$ Z_0 \f$ : line impedance
- * - \f$ Z_\mathrm{VACCUM} \f$ : vaccum impedance
+ * - \f$ Z_\mathrm{VACUUM} \f$ : vacuum impedance
  * - \f$ D_{in} \f$ : Wire diameter without insulation
  *
  * Reference for above equations :
diff --git a/pcbnew/exporters/export_hyperlynx.cpp b/pcbnew/exporters/export_hyperlynx.cpp
index 9be363ccb3..e61d7e3204 100644
--- a/pcbnew/exporters/export_hyperlynx.cpp
+++ b/pcbnew/exporters/export_hyperlynx.cpp
@@ -332,7 +332,7 @@ bool HYPERLYNX_EXPORTER::writeStackupInfo()
      * (SIGNAL T=thickness [P=plating_thickness] [C=constant] L=layer_name [M=material_name]) [comment]
      * (DIELECTRIC T=thickness [C=constant] [L=layer_name] [M=material_name]) [comment]
      * }
-     * name lenght is <= 20 chars
+     * name length is <= 20 chars
      */
 
     LSEQ layers = m_board->GetDesignSettings().GetEnabledLayers().CuStack();
diff --git a/pcbnew/plugins/altium/altium_parser_pcb.cpp b/pcbnew/plugins/altium/altium_parser_pcb.cpp
index d48429a8d6..4d15355246 100644
--- a/pcbnew/plugins/altium/altium_parser_pcb.cpp
+++ b/pcbnew/plugins/altium/altium_parser_pcb.cpp
@@ -317,7 +317,7 @@ ADIMENSION6::ADIMENSION6( ALTIUM_PARSER& aReader )
     linewidth      = ALTIUM_PARSER::PropertiesReadKicadUnit( properties, "LINEWIDTH", "10mil" );
     textheight     = ALTIUM_PARSER::PropertiesReadKicadUnit( properties, "TEXTHEIGHT", "10mil" );
     textlinewidth  = ALTIUM_PARSER::PropertiesReadKicadUnit( properties, "TEXTLINEWIDTH", "6mil" );
-    textprecission = ALTIUM_PARSER::PropertiesReadInt( properties, "TEXTPRECISION", 2 );
+    textprecision  = ALTIUM_PARSER::PropertiesReadInt( properties, "TEXTPRECISION", 2 );
     textbold       = ALTIUM_PARSER::PropertiesReadBool( properties, "TEXTLINEWIDTH", false );
     textitalic     = ALTIUM_PARSER::PropertiesReadBool( properties, "ITALIC", false );
 
diff --git a/pcbnew/plugins/altium/altium_parser_pcb.h b/pcbnew/plugins/altium/altium_parser_pcb.h
index 8092f5848f..215c40fefe 100644
--- a/pcbnew/plugins/altium/altium_parser_pcb.h
+++ b/pcbnew/plugins/altium/altium_parser_pcb.h
@@ -400,7 +400,7 @@ struct ADIMENSION6
     uint32_t linewidth;
     uint32_t textheight;
     uint32_t textlinewidth;
-    int32_t  textprecission;
+    int32_t  textprecision;
     bool     textbold;
     bool     textitalic;
 
diff --git a/pcbnew/plugins/altium/altium_pcb.cpp b/pcbnew/plugins/altium/altium_pcb.cpp
index f68e5e8109..cee646ca92 100644
--- a/pcbnew/plugins/altium/altium_pcb.cpp
+++ b/pcbnew/plugins/altium/altium_pcb.cpp
@@ -927,7 +927,7 @@ void ALTIUM_PCB::HelperParseDimensions6Linear( const ADIMENSION6& aElem )
     ALIGNED_DIMENSION* dimension = new ALIGNED_DIMENSION( m_board );
     m_board->Add( dimension, ADD_MODE::APPEND );
 
-    dimension->SetPrecision( aElem.textprecission );
+    dimension->SetPrecision( aElem.textprecision );
     dimension->SetLayer( klayer );
     dimension->SetStart( referencePoint0 );
diff --git a/eeschema/tools/sch_editor_control.cpp b/eeschema/tools/sch_editor_control.cpp
index 55d226a440..9cbffe3b5e 100644
--- a/eeschema/tools/sch_editor_control.cpp
+++ b/eeschema/tools/sch_editor_control.cpp
@@ -1244,10 +1244,10 @@ bool SCH_EDITOR_CONTROL::doCopy( bool aUseLocalClipboard )
 
     STRING_FORMATTER formatter;
     SCH_SEXPR_PLUGIN plugin;
-    SCH_SHEET_LIST   hiearchy = schematic.GetSheets();
+    SCH_SHEET_LIST   hierarchy = schematic.GetSheets();
     SCH_SHEET_PATH   selPath = m_frame->GetCurrentSheet();
 
-    plugin.Format( &selection, &selPath, &hiearchy, &formatter );
+    plugin.Format( &selection, &selPath, &hierarchy, &formatter );
 
     if( aUseLocalClipboard )
     {
@@ -1516,7 +1516,7 @@ int SCH_EDITOR_CONTROL::Paste( const TOOL_EVENT& aEvent )
     existingRefs.SortByReferenceOnly();
 
     // Keep track of pasted sheets and symbols for the different
     // paths to the hiearchy
     std::map<SCH_SHEET_PATH, SCH_REFERENCE_LIST> pastedSymbols;
     std::map<SCH_SHEET_PATH, SCH_SHEET_LIST>     pastedSheets;
 
@@ -1624,7 +1624,7 @@ int SCH_EDITOR_CONTROL::Paste( const TOOL_EVENT& aEvent )
             }
 
             //@todo: it might be better to just iterate through the sheet names
             // in this screen instead of the whole hiearchy.
             int uniquifier = std::max( 0, wxAtoi( number ) ) + 1;
 
             while( hierarchy.NameExists( candidateName ) )
@@ -1516,7 +1516,7 @@ int SCH_EDITOR_CONTROL::Paste( const TOOL_EVENT& aEvent )
 
     // Keep track of pasted sheets and symbols for the different
-    // paths to the hiearchy
+    // paths to the hierarchy
     std::map<SCH_SHEET_PATH, SCH_REFERENCE_LIST> pastedSymbols;
     std::map<SCH_SHEET_PATH, SCH_SHEET_LIST>     pastedSheets;
@@ -1624,7 +1624,7 @@ int SCH_EDITOR_CONTROL::Paste( const TOOL_EVENT& aEvent )
 
             //@todo: it might be better to just iterate through the sheet names
-            // in this screen instead of the whole hiearchy.
+            // in this screen instead of the whole hierarchy.
             int uniquifier = std::max( 0, wxAtoi( number ) ) + 1;
 